echo "complete _"										>> $EXTENSION/build_order.txt
echo "# $EXTENSION/build_order.txt" 				 	 > $EXTENSION/build_order.txt
echo "# <scriptname> (without .sh)" 					>> $EXTENSION/build_order.txt
echo "" 												>> $EXTENSION/build_order.txt
	
# Required
[[ $(command -v gdbus) == "" ]] && echo "Installing glib" && extension --install glib && echo "Finished glib"
[ ! -f /lib/libsigc-2.0.so ] && echo "Installing libsigcpp2" && extension --install libsigcpp2 && echo "Finished libsigcpp2"
# Optional
if [[ $INSTALL_OPTIONAL != false ]]; then 
	[[ $(command -v doxygen) == "" ]] && echo "Installing doxygen" && extension --install doxygen && echo "Finished doxygen"
	[[ $(command -v xsltproc) == "" ]] && echo "Installing libxslt" && extension --install libxslt && echo "Finished libxslt"
fi
# Tests
if [[ $INSTALL_TESTS != false ]]; then 
	[ ! -f /lib/libgiognomeproxy.so ] && echo "Installing glib_networking" && extension --install glib_networking && echo "Finished glib_networking"
	[[ $(command -v certtool) == "" ]] && echo "Installing gnutls" && extension --install gnutls && echo "Finished gnutls"
fi

if [ $BUILD_ALL == "false" ] && [ ! -f /lib/libgiomm-2.4.so ]; then
	echo "glibmm_24" 									>> $EXTENSION/build_order.txt
fi
if [ $BUILD_ALL == "true" ]; then
	echo "glibmm_24" 									>> $EXTENSION/build_order.txt
fi
echo "complete _" 										>> $EXTENSION/build_order.txt
